<?php

namespace TC\PaymentLogs\Admin\Controller;

use XF;
use XF\Admin\Controller\AbstractController;

class Statistics extends AbstractController
{
	/**
	 * @return XF\Mvc\Reply\View
	 */
	public function actionIndex()
	{
		$entries = $this->finder('XF:PaymentProviderLog')
			->with('Provider', true)
			->with([
				'PurchaseRequest.PaymentProfile',
				'PurchaseRequest.Purchasable',
				'PurchaseRequest.User'
			])
			->whereOr(['log_type' => 'payment'], ['log_type' => 'info', 'provider_id' => 'freekassa'])
			->order('provider_log_id', 'DESC');

		$startDate = $this->filter('start_date', 'datetime') ?: XF::$time - 60 * 60 * 24 * 30;
		$endDate = $this->filter('end_date', 'datetime') ?: XF::$time;
		$paymentProfileId = $this->filter('payment_profile_id', 'uint');

		if ($paymentProfileId)
		{
			$entries->where('PurchaseRequest.PaymentProfile.payment_profile_id', $paymentProfileId);
		}

		$entries->where('log_date', '>=', $startDate)->where('log_date', '<=', $endDate);

		/** @var XF\Entity\PaymentProviderLog[] $logs */
		$logs = $entries->fetch();

		/*
		 * Сортировка по платёжному шлюзу и валюте платежа
		 */
		$incomeData = [];
		foreach ($logs as $log)
		{
			if (!empty($incomeData[$log->PurchaseRequest->PaymentProfile->title][$log->PurchaseRequest->cost_currency]))
			{
				$incomeData[$log->PurchaseRequest->PaymentProfile->title][$log->PurchaseRequest->cost_currency] += $log->PurchaseRequest->cost_amount;
			}
			else
			{
				$incomeData[$log->PurchaseRequest->PaymentProfile->title][$log->PurchaseRequest->cost_currency] = $log->PurchaseRequest->cost_amount;
			}
		}

		$paymentProfiles[0] = XF::phrase('(choose_payment_method)');
		$paymentProfiles += XF::repository('XF:Payment')->findPaymentProfilesForList()->fetch()->pluck(function (XF\Entity\PaymentProfile $profile) {
			return [
				$profile->payment_profile_id,
				$profile->title
			];
		}, true);

		$viewParams = [
			'entries'         => $logs,
			'incomeData'      => $incomeData,
			'paymentProfiles' => $paymentProfiles,

			'linkParams' => [
				'startDate'          => $startDate,
				'endDate'            => $endDate,
				'payment_profile_id' => $paymentProfileId
			]
		];

		return $this->view('TC\PaymentLogs:Statistics\Index', 'tc_pl_log_payment_provider_list', $viewParams);
	}
}
